.. currentmodule:: abjad.tools.timespantools

timespan_2_overlaps_only_start_of_timespan_1
============================================

.. autofunction:: timespan_2_overlaps_only_start_of_timespan_1
